@@ -1,4 +1,5 @@
 import math
+import warnings
 
 from pyaedt.edb_core.general import convert_py_list_to_net_list
 from pyaedt.generic.general_methods import pyaedt_function_handler
@@ -330,6 +331,11 @@ class EDBPadstack(object):
             self.thermalpad_by_layer[layer] = EDBPadProperties(edb_padstack, layer, 2, self)
         pass
 
+    @property
+    def name(self):
+        """Padstack Definition Name."""
+        return self.edb_padstack.GetName()
+
     @property
     def _padstack_methods(self):
         return self._ppadstack._padstack_methods
@@ -610,6 +616,115 @@ class EDBPadstack(object):
         newPadstackDefinitionData.SetMaterial(materialname)
         self.edb_padstack.SetData(newPadstackDefinitionData)
 
+    @property
+    def padstack_instances(self):
+
+        """Get all the vias that belongs to active Padstack definition.
+
+        Returns
+        -------
+        dict
+        """
+        return {
+            id: via for id, via in self._ppadstack.padstack_instances.items() if via.padstack_definition == self.name
+        }
+
+    @pyaedt_function_handler()
+    def convert_to_microvias(self, convert_only_signal_vias=True, aspect_ratio=0.75):
+        """Convert actual padstack instance to microvias with a given aspect ration.
+
+        Parameters
+        ----------
+        convert_only_signal_vias : bool, optional
+            Either to convert only vias belonging to signal nets or all vias. Defaults is ``True``.
+        aspect_ratio : float, optional
+            Ratio between top and bottom face of trapezoid. The default value is ``0.75``.
+
+        Returns
+        -------
+        bool
+        """
+        if self.via_start_layer == self.via_stop_layer:
+            self._ppadstack._pedb.logger.error("Microvias cannot be applied when Start and Stop Layers are the same.")
+        layout = self._ppadstack._pedb._active_layout
+        layers = self._ppadstack._pedb.stackup.signal_layers
+        layer_names = [i for i in list(layers.keys())]
+        if abs(layer_names.index(self.via_start_layer) - layer_names.index(self.via_stop_layer)) > 1:
+            self._ppadstack._pedb.logger.error(
+                "Microvias cannot be applied when Start and Stop Layers are not adjacent."
+            )
+        if convert_only_signal_vias:
+            signal_nets = [i for i in list(self._ppadstack._pedb.core_nets.signal_nets.keys())]
+        topl, topz, bottoml, bottomz = self._ppadstack._pedb.stackup.stackup_limits(True)
+        start_elevation = layers[self.via_start_layer].lower_elevation
+
+        rad1 = self.hole_properties[0] / 2
+        rad2 = rad1 * aspect_ratio
+        if start_elevation < (topz + bottomz) / 2:
+            rad1, rad2 = rad2, rad1
+        i = 0
+        for via in list(self.padstack_instances.values()):
+            if convert_only_signal_vias and via.net_name in signal_nets or not convert_only_signal_vias:
+                pos = via.position
+                cloned_circle = self._edb.Cell.Primitive.Circle.Create(
+                    layout,
+                    self.via_start_layer,
+                    via._edb_padstackinstance.GetNet(),
+                    self._get_edb_value(pos[0]),
+                    self._get_edb_value(pos[1]),
+                    self._get_edb_value(rad1),
+                )
+                if len(self.pad_by_layer[self.via_start_layer].parameters) == 0:
+                    self._edb.Cell.Primitive.Polygon.Create(
+                        layout,
+                        self.via_start_layer,
+                        via._edb_padstackinstance.GetNet(),
+                        self.pad_by_layer[self.via_start_layer].polygon_data,
+                    )
+                else:
+                    self._edb.Cell.Primitive.Circle.Create(
+                        layout,
+                        self.via_start_layer,
+                        via._edb_padstackinstance.GetNet(),
+                        self._get_edb_value(pos[0]),
+                        self._get_edb_value(pos[1]),
+                        self._get_edb_value(self.pad_by_layer[self.via_start_layer].parameters_values[0] / 2),
+                    )
+
+                cloned_circle2 = self._edb.Cell.Primitive.Circle.Create(
+                    layout,
+                    self.via_stop_layer,
+                    via._edb_padstackinstance.GetNet(),
+                    self._get_edb_value(pos[0]),
+                    self._get_edb_value(pos[1]),
+                    self._get_edb_value(rad2),
+                )
+                if len(self.pad_by_layer[self.via_stop_layer].parameters) == 0:
+                    self._edb.Cell.Primitive.Polygon.Create(
+                        layout,
+                        self.via_stop_layer,
+                        via._edb_padstackinstance.GetNet(),
+                        self.pad_by_layer[self.via_stop_layer].polygon_data,
+                    )
+                else:
+                    self._edb.Cell.Primitive.Circle.Create(
+                        layout,
+                        self.via_stop_layer,
+                        via._edb_padstackinstance.GetNet(),
+                        self._get_edb_value(pos[0]),
+                        self._get_edb_value(pos[1]),
+                        self._get_edb_value(self.pad_by_layer[self.via_stop_layer].parameters_values[0] / 2),
+                    )
+                s3d = self._edb.Cell.Hierarchy.Structure3D.Create(layout, "via3d_{}".format(via.id))
+                s3d.AddMember(cloned_circle)
+                s3d.AddMember(cloned_circle2)
+                s3d.SetMaterial(self.material)
+                s3d.SetMeshClosureProp(self._edb.Cell.Hierarchy.Structure3D.TClosure.EndsClosed)
+                via.delete()
+                i += 1
+        self._ppadstack._pedb.logger.info("{} Converted successfully to 3D Objects.".format(i))
+        return True
+
 
 class EDBPadstackInstance(object):
     """Manages EDB functionalities for a padstack.
@@ -641,6 +756,18 @@ class EDBPadstackInstance(object):
         self._edb_padstackinstance = edb_padstackinstance
         self._pedb = _pedb
         self._bounding_box = []
+        self._object_instance = None
+
+    @property
+    def object_instance(self):
+        """Edb Object Instance."""
+        if not self._object_instance:
+            self._object_instance = (
+                self._edb_padstackinstance.GetLayout()
+                .GetLayoutInstance()
+                .GetLayoutObjInstance(self._edb_padstackinstance, None)
+            )
+        return self._object_instance
 
     @property
     def bounding_box(self):
@@ -653,12 +780,7 @@ class EDBPadstackInstance(object):
         """
         if self._bounding_box:
             return self._bounding_box
-        bbox = (
-            self._edb_padstackinstance.GetLayout()
-            .GetLayoutInstance()
-            .GetLayoutObjInstance(self._edb_padstackinstance, None)
-            .GetBBox()
-        )
+        bbox = self.object_instance.GetBBox()
         self._bounding_box = [
             [bbox.Item1.X.ToDouble(), bbox.Item1.Y.ToDouble()],
             [bbox.Item2.X.ToDouble(), bbox.Item2.Y.ToDouble()],
@@ -666,7 +788,7 @@ class EDBPadstackInstance(object):
         return self._bounding_box
 
     @pyaedt_function_handler()
-    def in_polygon(self, polygon_data, include_partial=True):
+    def in_polygon(self, polygon_data, include_partial=True, simple_check=False):
         """Check if padstack Instance is in given polygon data.
 
         Parameters
@@ -680,9 +802,21 @@ class EDBPadstackInstance(object):
         bool
             ``True`` when successful, ``False`` when failed.
         """
-        plane = self._pedb.core_primitives.Shape("rectangle", pointA=self.bounding_box[0], pointB=self.bounding_box[1])
-        rectangle_data = self._pedb.core_primitives.shape_to_polygon_data(plane)
-        int_val = polygon_data.GetIntersectionType(rectangle_data)
+        if simple_check:
+            pos = [i for i in self.position]
+            int_val = (
+                1
+                if polygon_data.PointInPolygon(
+                    self._pedb.edb.Geometry.PointData(self._pedb.edb_value(pos[0]), self._pedb.edb_value(pos[1]))
+                )
+                else 0
+            )
+        else:
+            plane = self._pedb.core_primitives.Shape(
+                "rectangle", pointA=self.bounding_box[0], pointB=self.bounding_box[1]
+            )
+            rectangle_data = self._pedb.core_primitives.shape_to_polygon_data(plane)
+            int_val = polygon_data.GetIntersectionType(rectangle_data)
         # Intersection type:
         # 0 = objects do not intersect
         # 1 = this object fully inside other (no common contour points)
@@ -697,6 +831,15 @@ class EDBPadstackInstance(object):
         else:
             return False
 
+    @property
+    def component(self):
+        """Get component this padstack belong to."""
+        comp_name = self._edb_padstackinstance.GetComponent().GetName()
+        if comp_name in self._pedb.core_components.components:
+            return self._pedb.core_components.components[comp_name]
+        else:  # pragma: no cover
+            return
+
     @property
     def pin(self):
         """Return Edb padstack object."""
@@ -767,8 +910,8 @@ class EDBPadstackInstance(object):
 
     @start_layer.setter
     def start_layer(self, layer_name):
-        stop_layer = self._pedb.core_stackup.signal_layers[self.stop_layer]._layer
-        layer = self._pedb.core_stackup.signal_layers[layer_name]._layer
+        stop_layer = self._pedb.stackup.signal_layers[self.stop_layer]._edb_layer
+        layer = self._pedb.stackup.signal_layers[layer_name]._edb_layer
         self._edb_padstackinstance.SetLayerRange(layer, stop_layer)
 
     @property
@@ -789,10 +932,35 @@ class EDBPadstackInstance(object):
 
     @stop_layer.setter
     def stop_layer(self, layer_name):
-        start_layer = self._pedb.core_stackup.signal_layers[self.start_layer]._layer
-        layer = self._pedb.core_stackup.signal_layers[layer_name]._layer
+        start_layer = self._pedb.stackup.signal_layers[self.start_layer]._edb_layer
+        layer = self._pedb.stackup.signal_layers[layer_name]._edb_layer
         self._edb_padstackinstance.SetLayerRange(start_layer, layer)
 
+    @property
+    def layer_range_names(self):
+        """List of all layers to which the padstack instance belongs."""
+        _, start_layer, stop_layer = self._edb_padstackinstance.GetLayerRange()
+        started = False
+        layer_list = []
+        start_layer_name = start_layer.GetName()
+        stop_layer_name = stop_layer.GetName()
+        for layer_name in list(self._pedb.stackup.layers.keys()):
+            if started:
+                layer_list.append(layer_name)
+                if layer_name == stop_layer_name or layer_name == start_layer_name:
+                    break
+            elif layer_name == start_layer_name:
+                started = True
+                layer_list.append(layer_name)
+                if layer_name == stop_layer_name:
+                    break
+            elif layer_name == stop_layer_name:
+                started = True
+                layer_list.append(layer_name)
+                if layer_name == start_layer_name:
+                    break
+        return layer_list
+
     @property
     def net_name(self):
         """Net name.
@@ -804,6 +972,19 @@ class EDBPadstackInstance(object):
         """
         return self._edb_padstackinstance.GetNet().GetName()
 
+    @net_name.setter
+    def net_name(self, val):
+        if val in self._pedb.core_nets.nets:
+            net = self._pedb.core_nets.nets[val].net_object
+            self._edb_padstackinstance.SetNet(net)
+        elif not isinstance(val, str):
+            try:
+                self._edb_padstackinstance.SetNet(val)
+            except:
+                raise AttributeError("Value inserted not found. Input has to be net name or net object.")
+        else:
+            raise AttributeError("Value inserted not found. Input has to be net name or net object.")
+
     @property
     def is_pin(self):
         """Determines whether this padstack instance is a layout pin.
@@ -835,11 +1016,10 @@ class EDBPadstackInstance(object):
         list
             List of ``[x, y]``` coordinates for the padstack instance position.
         """
-        point_data = self._pedb.edb.Geometry.PointData(self._pedb.edb_value(0.0), self._pedb.edb_value(0.0))
         out = self._edb_padstackinstance.GetPositionAndRotationValue()
-
         if out[0]:
             return [out[1].X.ToDouble(), out[1].Y.ToDouble()]
+        return []
 
     @position.setter
     def position(self, value):
@@ -893,6 +1073,11 @@ class EDBPadstackInstance(object):
         self._edb_padstackinstance.SetName(value)
         self._edb_padstackinstance.SetProductProperty(self._pedb.edb.ProductId.Designer, 11, value)
 
+    @property
+    def pin_number(self):
+        """Get pin number."""
+        return self._edb_padstackinstance.GetName()
+
     @pyaedt_function_handler()
     def parametrize_position(self, prefix=None):
         """Parametrize the instance position.
@@ -920,8 +1105,20 @@ class EDBPadstackInstance(object):
 
     @pyaedt_function_handler()
     def delete_padstack_instance(self):
+        """Delete this padstack instance.
+
+        .. deprecated:: 0.6.28
+           Use :func:`delete` property instead.
+        """
+        warnings.warn("`delete_padstack_instance` is deprecated. Use `delete` instead.", DeprecationWarning)
+        self._edb_padstackinstance.Delete()
+        return True
+
+    @pyaedt_function_handler()
+    def delete(self):
         """Delete this padstack instance."""
         self._edb_padstackinstance.Delete()
+        return True
 
     @pyaedt_function_handler()
     def in_voids(self, net_name=None, layer_name=None):
@@ -1200,3 +1397,16 @@ class EDBPadstackInstance(object):
             path = self._pedb.core_primitives.Shape("polygon", points=new_rect)
             created_polygon = self._pedb.core_primitives.create_polygon(path, layer_name)
             return created_polygon
+
+    @pyaedt_function_handler()
+    def get_connected_object_id_set(self):
+        """Produce a list of all geometries physically connected to a given layout object.
+
+        Returns
+        -------
+        list
+            Found connected objects IDs with Layout object.
+        """
+        layoutInst = self._edb_padstackinstance.GetLayout().GetLayoutInstance()
+        layoutObjInst = self.object_instance
+        return [loi.GetLayoutObj().GetId() for loi in layoutInst.GetConnectedObjects(layoutObjInst).Items]
