@@ -2,24 +2,14 @@
 This module contains these classes: `EdbLayout` and `Shape`.
 """
 import math
-import os
-import warnings
 
 from pyaedt.edb_core.edb_data.primitives_data import EDBPrimitives
 from pyaedt.edb_core.edb_data.simulation_configuration import SimulationConfiguration
 from pyaedt.edb_core.edb_data.utilities import EDBStatistics
 from pyaedt.edb_core.general import convert_py_list_to_net_list
+from pyaedt.generic.clr_module import Tuple
 from pyaedt.generic.general_methods import pyaedt_function_handler
 
-try:
-    from System import Tuple
-
-    # from System.Collections.Generic import List
-
-except ImportError:
-    if os.name != "posix":
-        warnings.warn("This module requires the PythonNET package.")
-
 
 class EdbLayout(object):
     """Manages EDB methods for primitives management accessible from `Edb.core_primitives` property.
@@ -32,9 +22,7 @@ class EdbLayout(object):
     """
 
     def __init__(self, p_edb):
-        self._prims = []
         self._pedb = p_edb
-        # self.update_primitives()
 
     @property
     def _edb(self):
@@ -78,25 +66,7 @@ class EdbLayout(object):
         dict
             Dictionary of layers.
         """
-        return self._pedb.core_stackup.stackup_layers.layers
-
-    @pyaedt_function_handler()
-    def update_primitives(self):
-        """
-        Update a primitives list from the EDB database.
-
-        Returns
-        -------
-        bool
-            ``True`` when successful, ``False`` when failed.
-        """
-        if self._active_layout:
-            self._prims = []
-            for lay_obj in list(self._active_layout.Primitives):
-                self._prims.append(EDBPrimitives(lay_obj, self._pedb))
-            self._logger.info("Primitives Updated")
-            return True
-        return False
+        return self._pedb.stackup.layers
 
     @property
     def primitives(self):
@@ -107,9 +77,11 @@ class EdbLayout(object):
         list of :class:`pyaedt.edb_core.edb_data.primitives_data.EDBPrimitives`
             List of primitives.
         """
-        if not self._prims:
-            self.update_primitives()
-        return self._prims
+        _prims = []
+        if self._active_layout:
+            for lay_obj in list(self._active_layout.Primitives):
+                _prims.append(EDBPrimitives(lay_obj, self._pedb))
+        return _prims
 
     @property
     def polygons_by_layer(self):
@@ -126,8 +98,37 @@ class EdbLayout(object):
         return _primitives_by_layer
 
     @property
-    def _primitives_by_layer(self):
-        return self.polygons_by_layer
+    def primitives_by_net(self):
+        """Primitives with net names as keys.
+
+        Returns
+        -------
+        dict
+            Dictionary of primitives with nat names as keys.
+        """
+        _prim_by_net = {}
+        for net in list(self._pedb.core_nets.nets.keys()):
+            _prim_by_net[net] = [
+                EDBPrimitives(i, self._pedb) for i in self._active_layout.Primitives if i.GetNet().GetName() == net
+            ]
+        return _prim_by_net
+
+    @property
+    def primitives_by_layer(self):
+        """Primitives with layer names as keys.
+
+        Returns
+        -------
+        dict
+            Dictionary of primitives with layer names as keys.
+        """
+        _primitives_by_layer = {}
+        for lay in self.layers:
+            _primitives_by_layer[lay] = []
+        for i in self._active_layout.Primitives:
+            lay = i.GetLayer().GetName()
+            _primitives_by_layer[lay].append(EDBPrimitives(i, self._pedb))
+        return _primitives_by_layer
 
     @property
     def rectangles(self):
@@ -448,15 +449,6 @@ class EdbLayout(object):
         if polygon.IsNull():
             self._logger.error("Null path created")
             return False
-        else:
-            if not self._prims:
-                self.update_primitives()
-            else:
-                self._prims.append(EDBPrimitives(polygon, self._pedb))
-                if layer_name in self._primitives_by_layer:
-                    self._primitives_by_layer[layer_name].append(polygon)
-                else:
-                    self._primitives_by_layer[layer_name] = [polygon]
         return polygon
 
     @pyaedt_function_handler()
@@ -497,11 +489,10 @@ class EdbLayout(object):
 
         Returns
         -------
-        bool
-            ``True`` when successful, ``False`` when failed.
+        pyaedt.edb_core.edb_data.primitives_data.EDBPrimitives
         """
         path = self.Shape("Polygon", points=path_list)
-        return self.create_path(
+        primitive = self.create_path(
             path,
             layer_name=layer_name,
             net_name=net_name,
@@ -511,6 +502,8 @@ class EdbLayout(object):
             corner_style=corner_style,
         )
 
+        return EDBPrimitives(primitive, self._pedb)
+
     @pyaedt_function_handler()
     def create_polygon(self, main_shape, layer_name, voids=[], net_name=""):
         """Create a polygon based on a list of points and voids.
@@ -532,12 +525,18 @@ class EdbLayout(object):
             Polygon when successful, ``False`` when failed.
         """
         net = self._pedb.core_nets.find_or_create_net(net_name)
-        polygonData = self.shape_to_polygon_data(main_shape)
+        if isinstance(main_shape, EdbLayout.Shape):
+            polygonData = self.shape_to_polygon_data(main_shape)
+        else:
+            polygonData = main_shape
         if polygonData is None or polygonData.IsNull() or polygonData is False:
             self._logger.error("Failed to create main shape polygon data")
             return False
         for void in voids:
-            voidPolygonData = self.shape_to_polygon_data(void)
+            if isinstance(void, EdbLayout.Shape):
+                voidPolygonData = self.shape_to_polygon_data(void)
+            else:
+                voidPolygonData = void
             if voidPolygonData is None or voidPolygonData.IsNull() or polygonData is False:
                 self._logger.error("Failed to create void polygon data")
                 return False
@@ -547,14 +546,6 @@ class EdbLayout(object):
             self._logger.error("Null polygon created")
             return False
         else:
-            if not self._prims:
-                self.update_primitives()
-            else:
-                self._prims.append(EDBPrimitives(polygon, self._pedb))
-                if layer_name in list(self._primitives_by_layer.keys()):
-                    self._primitives_by_layer[layer_name].append(polygon)
-                else:
-                    self._primitives_by_layer[layer_name] = [polygon]
             return polygon
 
     @pyaedt_function_handler()
@@ -632,6 +623,33 @@ class EdbLayout(object):
                 self._get_edb_value(rotation),
             )
 
+    @pyaedt_function_handler
+    def delete_primitives(self, net_names):
+        """Delete primitives by net names.
+
+        Parameters
+        ----------
+        net_names : str, list
+            Names of the nets to delete.
+
+        Returns
+        -------
+        bool
+            ``True`` when successful, ``False`` when failed.
+
+        References
+        ----------
+
+        >>> Edb.core_primitives.delete_primitives(net_names=["GND"])
+        """
+        if not isinstance(net_names, list):  # pragma: no cover
+            net_names = [net_names]
+
+        for p in self.primitives[:]:
+            if p.net_name in net_names:
+                p.delete()
+        return True
+
     @pyaedt_function_handler()
     def get_primitives(self, net_name=None, layer_name=None, prim_type=None, is_void=False):
         """Get primitives by conditions.
@@ -699,7 +717,6 @@ class EdbLayout(object):
             if res:
                 cloned_circle.SetIsNegative(True)
                 void_circle.Delete()
-        self.update_primitives()
         return True
 
     @pyaedt_function_handler()
@@ -986,7 +1003,7 @@ class EdbLayout(object):
         if isinstance(layer_name, str):
             layer_name = [layer_name]
         if not layer_name:
-            layer_name = list(self._pedb.core_stackup.signal_layers.keys())
+            layer_name = list(self._pedb.stackup.signal_layers.keys())
 
         for lay in layer_name:
             self._logger.info("Uniting Objects on layer %s.", lay)
@@ -1034,7 +1051,6 @@ class EdbLayout(object):
                 p1 = self._pedb.core_padstack.padstacks[pad].edb_padstack.GetData()
                 if len(p1.GetLayerNames()) > 1:
                     self._pedb.core_padstack.remove_pads_from_padstack(pad)
-        self.update_primitives()
         return True
 
     @pyaedt_function_handler()
@@ -1185,7 +1201,7 @@ class EdbLayout(object):
 
         """
         stat_model = EDBStatistics()
-        stat_model.num_layers = len(list(self._pedb.core_stackup.stackup_layers.layers.values()))
+        stat_model.num_layers = len(list(self._pedb.stackup.stackup_layers.values()))
         stat_model.num_capacitors = len(self._pedb.core_components.capacitors)
         stat_model.num_resistors = len(self._pedb.core_components.resistors)
         stat_model.num_inductors = len(self._pedb.core_components.inductors)
@@ -1202,7 +1218,7 @@ class EdbLayout(object):
         stat_model.num_traces = len(self._pedb.core_primitives.paths)
         stat_model.num_polygons = len(self._pedb.core_primitives.polygons)
         stat_model.num_vias = len(self._pedb.core_padstack.padstack_instances)
-        stat_model.stackup_thickness = self._pedb.core_stackup.get_layout_thickness()
+        stat_model.stackup_thickness = self._pedb.stackup.get_layout_thickness()
         if evaluate_area:
             if net_list:
                 netlist = list(self._pedb.core_nets.nets.keys())
