@@ -27,7 +27,7 @@ class Mesh3DOperation(PropsManager, object):
     name :
 
     props : dict
-        Dictionary of the properites.
+        Dictionary of the properties.
 
     """
 
@@ -118,8 +118,8 @@ class Mesh3DOperation(PropsManager, object):
 class Mesh3d(object):
     """Mesh class.
 
-    This class provides the main AEDT mesh functionaility. The inherited class
-    `AEDTConfig` contains all `_desktop` hierarchical calls needed by this class.
+    Provides the main AEDT mesh functionality. The inherited class
+    ``AEDTConfig`` contains all ``_desktop`` hierarchical calls needed by this class.
 
     Parameters
     ----------
@@ -180,7 +180,7 @@ class Mesh3d(object):
         ----------
         setup_name : str
             Name of the setup.
-        mesh_name :str
+        mesh_name : str
             Name of the mesh.
 
         Returns
